# coding=utf-8
""""""
from __future__ import absolute_import, division, print_function

from .schema import indexable_role
from .service import service

__all__ = ['service', 'indexable_role']
